from setuptools import setup

setup(name='naefdistributions',
      version='0.2',
      description='Gaussian and Binomial distributions',
      packages=['naefdistributions'],
      author = 'Rico Naef',
      author_email = 'naefrico@gmail.com',
      zip_safe=False)